SystemOrganization addCategory: #'Smagick-Win32'!

!SmagickEnvironment class methodsFor: '*smagick-win32' stamp: 'ul 8/20/2007 01:25'!
morphicViewFolderSelector: aDir
	"Code taken from FileList2"

	| aFileList window fixedSize |
	aFileList _ FileList2 new directory: aDir.
	aFileList optionalButtonSpecs: aFileList servicesForFolderSelector.
	window _ (SystemWindow labelled: aDir pathName) model: aFileList.
	aFileList modalView: window.

	fixedSize _ 25.
	FileList2 addFullPanesTo: window from: {
		{FileList2 textRow: 'Please select the folder of your ImageMagick installation'. 0 @ 0 corner: 1 @ 0. 
				0@0 corner: 0@fixedSize}.
		{aFileList optionalButtonRow. 0 @ 0 corner: 1 @ 0. 
				0@fixedSize corner: 0@(fixedSize * 2)}.
		{aFileList morphicDirectoryTreePane. 0@0 corner: 1@1.
				0@(fixedSize * 2) corner: 0@0}.
	}.
	aFileList postOpen.
	^ window ! !

!SmagickEnvironment class methodsFor: '*smagick-win32' stamp: 'ul 8/20/2007 01:25'!
requestDirectory
	"Code taken from FileList2"

	| window fileModel dir |
	dir := Current 
		ifNotNilDo: [ :env | FileDirectory on: env installationPath ]
		ifNil: [ FileDirectory default ].
	window _ self morphicViewFolderSelector: dir.
	fileModel _ window model.
	window openInWorld: FileList2 currentWorld extent: 400@400.
	FileList2 modalLoopOn: window.
	^fileModel getSelectedDirectory withoutListWrapper! !

!SmagickEnvironment class methodsFor: '*smagick-win32' stamp: 'ul 8/20/2007 01:26'!
setup
	(self requestDirectory ifNotNilDo: [ :directory | self setup: directory fullName ])
		ifNotNilDo: [ :env | self finishSetup: env ]! !

!SmagickEnvironment class methodsFor: '*smagick-win32' stamp: 'ul 8/19/2007 21:18'!
validate: aPath

	| directory |
	^ (directory := FileDirectory on: aPath) exists
		and: [ self root tools anySatisfy: [ :each |
			[ directory fileExists: each command ]
				on: Error
				do: [ true ] ] ]! !

!SmagickEnvironment methodsFor: '*smagick-win32' stamp: 'ul 8/19/2007 21:48'!
commandFor: aTool

	^ String streamContents: [ :stream |
		stream
			nextPut: $";
			nextPutAll: self installationPath.
		self installationPath last = FileDirectory pathNameDelimiter
			ifFalse: [ stream nextPut: FileDirectory pathNameDelimiter ].
		stream 
			nextPutAll: aTool command;
			nextPutAll: '.exe"';
			space ]
	! !

!SmagickEnvironment methodsFor: '*smagick-win32' stamp: 'ul 8/20/2007 13:45'!
parseModule: aCollection
	"Junky code without regex. Not that nice."

	^(({ aCollection first } allSatisfy: [ :each | each asUppercase = each ]) 
		and: [ 
			| result |
			result := aCollection second size = 3.
			result ifTrue: [
				#('r-' 'w-' '+-') with: aCollection second do: [ :pattern :character |
					result := result and: [ pattern includes: character ] ] ].
			result ] )
		ifTrue: [ SmagickModule new
					name: aCollection third;
					format: (aCollection first copyReplaceAll: '*' with: '');
					read: (aCollection second first asLowercase = $r);
					write: (aCollection second second asLowercase = $w);
					multiImage: (aCollection second third = $+);
					nativeBlob: (aCollection first last = $*);
					yourself ]
		ifFalse: [ nil ]! !

!SmagickEnvironment methodsFor: '*smagick-win32' stamp: 'ul 8/20/2007 13:46'!
parseModules: anImageIO

	| modules rawModules rawTokens |
	" initialize parser "
	modules := SmagickModules new.
	rawModules := (anImageIO stream subStrings: String crlf).
	rawModules size < 3 ifTrue: [ ^ modules ].
	
	" get rid of the header and footer "
	rawModules := rawModules copyFrom: 3 to: rawModules size - 1. 
	
	" parde the body "
	rawModules do: [ :line |
		rawTokens := line substrings.
		rawTokens size < 3 
			ifFalse: [ 
				rawTokens at: 3 put: (String streamContents: [ :stream |
					stream nextPutAll: rawTokens third.
					4 to: rawTokens size do: [ :i |
						stream nextPutAll: ' ', (rawTokens at: i) ] ]).
				rawTokens := rawTokens first: 3.
				(self parseModule: rawTokens)
					ifNotNilDo: [ :module | modules add: module ] ] ].
	^ modules! !

!SmagickEnvironment methodsFor: '*smagick-win32' stamp: 'ul 8/19/2007 21:19'!
processor

	^MockOSProcessParsedIOForWin32! !

Object subclass: #MockOSProcessParsedIOForWin32
	instanceVariableNames: 'model command parser executed succeeded output error'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smagick-Win32'!

!MockOSProcessParsedIOForWin32 commentStamp: 'ul 8/19/2007 22:37' prior: 0!
I'm a mock class, I act as an OSProcess and an OSProcessParsedIO for Smagick. I use ProcessWrapper for external process execution.!

!MockOSProcessParsedIOForWin32 class methodsFor: 'as yet unclassified' stamp: 'ul 8/20/2007 01:43'!
initialize

	super initialize.
	SmagickEnvironment setup
	! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 18:32'!
command: aSelectorSymbol

	command := aSelectorSymbol! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/20/2007 23:30'!
execute
	
	| process commandString |
	process := ProcessWrapper new
		useStdout;
		useStderr;
		yourself.
	commandString := model perform: command.
	(succeeded := process startWithCommand: commandString) ifTrue: [
		process close.
		(succeeded := process waitForExit) ifTrue: [.
			output := process upToEnd.
			error := process stderrStream upToEnd.
			succeeded := process exitCode isZero and: [ error = '' ] ] ].
	executed := true! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 21:12'!
executed

	^executed! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 21:13'!
initialize

	executed := false.
	succeeded := false! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 18:31'!
model: anObject

	model := anObject! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/26/2007 16:09'!
outputString

	^self stream! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 18:32'!
parser: aSelectorSymbol

	parser := aSelectorSymbol! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 21:12'!
process
	
	^self! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/20/2007 22:10'!
result

	executed ifFalse: [ self execute ].
	^model perform: parser with: self

	! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 21:22'!
stream

	^ output asString! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 21:21'!
streamTarget: aSelectorSymbol
! !

!MockOSProcessParsedIOForWin32 methodsFor: 'as yet unclassified' stamp: 'ul 8/19/2007 21:13'!
succeeded 	
	
	^executed and: [ succeeded ]! !

!SmagickTransformation methodsFor: '*smagick-win32' stamp: 'ul 8/20/2007 23:35'!
assertFileWritePermission: aFile
	"Removed existence check of the directory. Not that nice."
	
	| file |
	[ (file := (FileStream forceNewFileNamed: aFile)) 
		ifNotNil: [ FileDirectory deleteFilePath: aFile ]
		ifNil: [ SmagickDestinationHasNoWritePermission signal ] ]
		ensure: [ file ifNotNil: [ file close ] ]! !
MockOSProcessParsedIOForWin32 initialize!
